@@ -7,6 +7,26 @@ CISCO_AC_OBJNAME=123456789012345678901234567890123456789012345678901234567890123
 # CISCO_AC_TIMESTAMP is also required for signing
 # comment is after BASH_BASE_SIZE or else sign tool will find the comment
 
+# Check if the package architecture matches the device architecture
+checkArchitectureCompatibility() 
+{
+    VPNARCH=x86_64 
+
+    # Check the current device architecture
+    ARCH=$(uname -m)
+    if [ "$ARCH" != "x86_64" ] && [ "$ARCH" != "aarch64" ]; then
+        echo "Unknown architecture: $ARCH"
+        exit 1
+    fi
+
+    # Compare the VPN architecture with the device architecture
+    if [ "$VPNARCH" != "$ARCH" ]; then
+        echo "Architecture mismatch: Installer is for $VPNARCH, but the device is $ARCH."
+        echo "Installation aborted due to architecture mismatch!" >> /tmp/${LOGFNAME}
+        exit 1
+    fi
+}
+
 csc_vercmp() 
 {
     ver_from="${1:?missing from-version}"
@@ -30,7 +50,7 @@ checkInstalledVersion()
   # version of DART being installed has to be greater than the current DART version
   if [ -f ${DARTMANIFEST} ]; then
       DARTPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${DARTMANIFEST})
-      DARTCURRVERSION=5.1.10.233
+      DARTCURRVERSION=5.1.11.388
 
       existing_ver="$(csc_vercmp "$DARTPREVVERSION" "$DARTCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -66,7 +86,7 @@ UNINSTALL="${VPNBIN}/dart_uninstall.sh"
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+cisco-secure-client-linux64-5.1.10.233-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
+LOGFNAME=`date "+cisco-secure-client-linux64-5.1.11.388-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
 
 DARTMANIFEST="${INSTPREFIX}/ACManifestDART.xml"
 
@@ -117,6 +137,8 @@ if [ -f "license.txt" ]; then
     done
 fi
 
+checkArchitectureCompatibility
+
 checkInstalledVersion
 
 if [ "`basename $0`" != "dart_install.sh" ]; then
