@@ -2,7 +2,7 @@
 #
 
 BASH_BASE_SIZE=0x00000b4e
-CISCO_AC_TIMESTAMP=0x0000000068434ffa
+CISCO_AC_TIMESTAMP=0x00000000689e5407
 CISCO_AC_OBJNAME=iseposture_uninstall.sh                                                                                                                                                                                                                                         
 # BASH_BASE_SIZE=0x00000000 is required for signing
 # the comment is after or else the code signing tool will find the comment
@@ -47,6 +47,13 @@ rm -f ${CSC_INSTPREFIX}/${ISEPOSTUREMANIFEST}
 
 # Remove those pre-deploy files that we may have installed
 
+for f in ${ISEPLUGINFILES}; do
+    if [ -e ${CSC_PLUGINDIR}/$f ]; then
+       echo "rm -rf ${CSC_PLUGINDIR}/$f" >> "${LOG}"
+       rm -rf ${CSC_PLUGINDIR}/$f >> "${LOG}" 2>&1
+    fi
+done
+
 for f in ${ISEBINFILES}; do
     if [ -e ${CSC_BINDIR}/$f ]; then
        echo "rm -rf ${CSC_BINDIR}/$f" >> "${LOG}"
@@ -61,13 +68,6 @@ for f in ${ISELIBFILES}; do
     fi
 done
 
-for f in ${ISEPLUGINFILES}; do
-    if [ -e ${CSC_PLUGINDIR}/$f ]; then
-       echo "rm -rf ${CSC_PLUGINDIR}/$f" >> "${LOG}"
-       rm -rf ${CSC_PLUGINDIR}/$f >> "${LOG}" 2>&1
-    fi
-done
-
 echo "rm -rf ${ISEPOSTURE_SCRIPTDIR}" >> "${LOG}"
 rm -rf ${ISEPOSTURE_SCRIPTDIR} >> "${LOG}" 2>&1
 
@@ -119,13 +119,10 @@ SGu00v[K]taM?v޿Xr)Am&vhAX&+MYxρJ>@G_ɁPs#!Y`dT!8|fx8E0OcOL
 98Nn6!SZj>C3O8Tm]@3|╲!usRF4Kov7,?&C p)5\8U7	1.\9qᾜ
 &gN_zI.t<V+#{pk栺:?ERAHKMD@(V*/d<3(<ˏ
 ;{˷w(?/"lA\flņ&3Kjj@0HK4Q Y
-mP+JtRH!W;Eanh&`ȯc:VxN  U
-*I紾foҽN}e(BNLgqL
-/.eafn1ˑa3C [}ox]-gm:BFkVk&|7PkZ
-hLb7ir?ǩZ j!{d<̞q<t
-#yǹBo{bd?	XwZ
-4'Vc*zh3Vx@7'uLغ;N{H2BnT@kĵ.+j/q'+2,v@꾚A\#C% nlM|)5CҠjBoi
-5ytȮiMkWA0)a2Zm;}$&
-3J+6S5>RnDֿFYHLjD_ςW}=jX)%Lm]P"a4=fzEj*
->ߡo؎IFY_wIϑKC{<v3S  EY	)4Qyj*4gN#~H[BGp\̏_m+˨SSC]5rP}b:$.e/#tQ;tSm	G(Lh?m	gG"AO_ğ'M=Õ?s<k^8!#
-r*H>nmYeFN@\ʛ1䘊Ab̯1}kjIQw¹pKш9<O<v:XvMQuRQОeX/Ud䧼{\Vg3&.BH2&$#:	)!w@ůDU)^+]qu-:s1&ܔD@/\٧c[fbXCͲ=շOқ9j'N& Sm	UFJ1f}|
\ No newline at end of file
+mP+JtRH!W;Eanh&`ȯc:VxN  gv\%?}j3blfiݿאhMG`\Bs4;/+~5|r'c>{9vLf'u\93bgȰ
+^oӊR0)1P(˕6=p8j|Bt&olhԖM.1ӯuG'QUL{=t2z>*ND~%
+i1V+TV7BP8bLXs^|B< 0Ep)%`Iwf%w*qbk-6AGt>\
+Oɞ@4r{*_8{hPnPICCЪlOb{4e23@߳=
+p-cՊi`V@?]	QsZsv`^Tuq@u::
+Zn/3^G^+]%8ŧ#c\G}'rE"X^|}`84Jd%r  >	 0h*Չ ݽErL34Y?aO<".O؉(τa	IP_W֮d/OAb2Ck}nf!Uey@7՘	0ۏ\uS{1{MWY6s=b~VT%0.!3Ҙ&PuG&oVhOlgO';b}56|y@6>_I֋{H M݂^E ,^}pǚag+-Ai_N/өAe
+e蓻k0=ݛi؜0]E<m<)I𶝽2wOLh)cNPǃ*sXm;:p1΁t`OtVz˷%`o	F"Q~3ݰGR(gQ5aBbρUSy4Qw3yIyԇ\@8
\ No newline at end of file
