@@ -1,8 +1,8 @@
 #!/bin/sh
 #
 
-BASH_BASE_SIZE=0x00002050
-CISCO_AC_TIMESTAMP=0x0000000068435000
+BASH_BASE_SIZE=0x00002054
+CISCO_AC_TIMESTAMP=0x00000000689e540d
 CISCO_AC_OBJNAME=iseposture_install.sh                                                                                                                                                                                                                                           
 # BASH_BASE_SIZE=0x00000000 is required for signing
 # the comment is after or else the code signing tool will find the comment
@@ -42,7 +42,7 @@ ISEPOSTUREMANIFEST="ACManifestISEPosture.xml"
 ISEMIGRATIONFILES="ISEPostureCFG.xml ConnectionData.xml DGCacheRecords.xml ISEPreferences.xml"
 VPNMANIFEST="${CSC_INSTPREFIX}/ACManifestVPN.xml"
 
-LOGFNAME=`date "+csc-linux64-5.1.10.233-iseposture-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+csc-linux64-5.1.11.388-iseposture-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco Secure Client - ISE Posture"
 CURRENTDIR=`dirname $0 2> /dev/null`
 
@@ -196,12 +196,10 @@ done
 
 for f in ${ISEPLUGINFILES}; do
     echo "Installing "${INST_PLUGINDIR}/$f >> /tmp/${LOGFNAME}
-    ${INSTALL} -o root -m 755 ${INST_PLUGINDIR}/$f ${CSC_PLUGINDIR} || exit 1
+    ${INSTALL} -o root -m 755 ${INST_PLUGINDIR}/$f ${CSC_BINDIR} || exit 1
+    mv -f ${CSC_BINDIR}/$f ${CSC_PLUGINDIR} || exit 1
 done
 
-echo "done."
-echo "done." >> /tmp/${LOGFNAME}
-
 # update manifest
 echo "Updating AC manifest." >> /tmp/${LOGFNAME}
 
@@ -266,13 +264,17 @@ SGu00v[K]taM?v޿Xr)Am&vhAX&+MYxρJ>@G_ɁPs#!Y`dT!8|fx8E0OcOL
 98Nn6!SZj>C3O8Tm]@3|╲!usRF4Kov7,?&C p)5\8U7	1.\9qᾜ
 &gN_zI.t<V+#{pk栺:?ERAHKMD@(V*/d<3(<ˏ
 ;{˷w(?/"lA\flņ&3Kjj@0HK4Q Y
-mP+JtRH!W;Eanh&`ȯc:VxN  3hRS7D
-C^a-$7kwh
-E/%?#..2
-]X7OZ0'4}-9Lf0bugEgۜUGE~
-j!/GwFY !MuLwfw/0kNx,;2|3t1ޱQY.0]4
-W:"01ѧi* V|x$ju.\ʹt;	*1V 5|'Yf({ZexZ$_t,)+VN~TJ`x4J:$z%+vҿ>fUe35FXLtI]2lIh2	^hn?%x;v$A^V^ԭ,C<VHWOkvA"8!S+IҊlM7KXj1U2yҲrY~ );rK  E>dgz	6'Oj(lQ̼MU`c)t>m4'\2GU~ix
-Ɯ2oC显pP\o죢4RJ1R8)\NH`=vL;SlxyvB[A%wyn48j襴e`ėaChP52	)\i9߫HTHF[Ӗ3>­uK{ld_OJcCmQz4ZfAI آ\ܖ}5;!PB=Wok\w~ z+fB䌘qLL.fgSd)K1r=*jhGeY6B7?q(T[
-8M:#k2Ԁ|BW$lb-
-JqKI3K?3s֭1\yWxHs[H&&:(5HrYd[^=zѡ8j	8nHZEk
-jwhʽ׵.q
\ No newline at end of file
+mP+JtRH!W;Eanh&`ȯc:VxN  :*}	w
+5X}Z}͠BB(!h򶄃+szWza) >ut⹡4屠Hl颻@a业SPd"
+{߹N
+,N
+tq+!04I`6CCݽwQrWW
+x6>o];w͚nXQcGVw`Y{mzkFs뎃OZm(G 
+VdU"'ald#ьCy{":S)L%LUV`:V,Ȱ4i?rRǊqn-zC
+t߳~RQ!.Ǧ[HnܯolM.%;%7w
+.\$
+,y*><*h#<$&.F97 <?7
+&-7ځzF+ږZBsRW*ʘpϛu?ц
+#m ;acIj&CFe}Rٷf" ߳P  **b#FsF9lȓT;Kh=9`˵V}r	~9h;e.&f<e=Vajs؆߹eq3}Dz0ArB%L[pîo:Q21n$O4r`Pvz6PE)>'@ͪ.V}MHJc|RqT+B?)l2y6%IZ
+S,GEFDc䲡)X,-llI'.ɻ0%8Ptz k"(zbHUUOz>;w=Ie]7WJYVR,r\;+k!ZZ3V5iY.PaU_>VR
+ݩW7"2K;SW.)ABCuhqr(TWDR/yɫ*0z'դ!rƑcO^C
\ No newline at end of file
