@@ -147,7 +147,7 @@ checkVersionFeasibilityWithVPN()
   # version of NVM being installed has to be same as installed VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      NVMCURRVERSION=5.1.10.233
+      NVMCURRVERSION=5.1.11.388
 
       if [ "$STANDALONE_FLAG" = true ]; then
         failed=true
@@ -174,7 +174,7 @@ checkVersionFeasibilityWithNVM()
   # version of NVM being installed has to be greater than the current NVM version
   if [ "$STANDALONE_FLAG" = true ] && [ -f ${NVMMANIFEST} ]; then
       NVMPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
-      NVMCURRVERSION=5.1.10.233
+      NVMCURRVERSION=5.1.11.388
 
       existing_ver="$(csc_vercmp "$NVMPREVVERSION" "$NVMCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -196,6 +196,31 @@ checkVersionFeasibilityWithNVM()
   fi
 }
 
+checkBPFAndBTFSupport()
+{
+  # Check for eBPF support
+  if [ -d /sys/fs/bpf ]; then
+    echo "eBPF support detected via /sys/fs/bpf."
+    echo "eBPF support detected via /sys/fs/bpf." >> /tmp/${LOGFNAME}
+  else
+    echo "eBPF support not detected."
+    echo "eBPF support not detected." >> /tmp/${LOGFNAME}
+    return 1
+  fi
+
+  # Check for BTF support using /sys/kernel/btf/vmlinux
+  if [ -f /sys/kernel/btf/vmlinux ]; then
+    echo "BTF support detected via /sys/kernel/btf/vmlinux."
+    echo "BTF support detected via /sys/kernel/btf/vmlinux." >> /tmp/${LOGFNAME}
+  else
+    echo "BTF support not detected (/sys/kernel/btf/vmlinux not found)."
+    echo "BTF support not detected (/sys/kernel/btf/vmlinux not found)." >> /tmp/${LOGFNAME}
+    return 1
+  fi
+
+  return 0
+}
+
 buildKDF()
 {
   # build KDF first, if .ko doesn't exist.
@@ -207,19 +232,25 @@ buildKDF()
       ./build_ac_ko.sh build `pwd` >> /tmp/${LOGFNAME} 2>&1
       if [ $? != 0 ]; then
           echo "Failed to build Cisco Secure Client Kernel module."
-          echo "Exiting now."
-          exit 1
+          echo "Continuing installation without the kernel module."
+          return 1
       else
           echo "Cisco Secure Client Kernel module built successfully."
       fi
   fi
+  return 0
 }
 
 installKDF()
 {
   mkdir -p ${KERNELDRIVERDIR}
   echo "Installing "${NEWTEMP}/${ACKDFKO} >> /tmp/${LOGFNAME}
-  ${INSTALL} -o root -m 755 ${NEWTEMP}/${ACKDFKO} ${KERNELDRIVERDIR}  || exit 1
+  if ! ${INSTALL} -o root -m 755 ${NEWTEMP}/${ACKDFKO} ${KERNELDRIVERDIR}; then
+      echo "Failed to install the kernel module. Continuing installation without it." >> /tmp/${LOGFNAME}
+      echo "Failed to install the kernel module. Continuing installation without it."
+      return 1
+  fi
+
   echo "Updating kernel module dependencies"
   /sbin/depmod -a
 
@@ -230,10 +261,11 @@ installKDF()
   if ! /sbin/modprobe -q anyconnect_kdf; then
       echo "Error. Unable to load the Kernel driver." >> /tmp/${LOGFNAME}
       echo "Error. Unable to load the Kernel driver."
-      echo "Exiting installation." >> /tmp/${LOGFNAME}
-      echo "Exiting installation."
-      exit 1
+      echo "Continuing installation without the kernel module." >> /tmp/${LOGFNAME}
+      echo "Continuing installation without the kernel module."
+      return 1
   fi
+  return 0
 }
 
 createDir()
@@ -303,7 +335,7 @@ KERNELDRIVERDIR=/lib/modules/$(uname -r)/extra/cisco/
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+cisco-secure-client-linux64-5.1.10.233-nvm-install-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+cisco-secure-client-linux64-5.1.11.388-nvm-install-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco Secure Client - Network Visibility Module"
 VPNMANIFEST="${INSTPREFIX}/ACManifestVPN.xml"
 NVMMANIFEST="${INSTPREFIX}/ACManifestNVM.xml"
@@ -377,8 +409,17 @@ done
 
 extractAndUnarchive
 
+checkBPFAndBTFSupport
+BPF_BTF_SUPPORTED=$?
+
 # build KDF first, if .ko doesn't exist.
 buildKDF
+buildKDFStatus=$?
+
+if [ $BPF_BTF_SUPPORTED -ne 0 ] && [ $buildKDFStatus -ne 0 ]; then
+  echo "Error: Failed to build KDF. Exiting installation." >> /tmp/${LOGFNAME}
+  exit 1
+fi
 
 # Return to previous directory.
 cd - >/dev/null
@@ -427,9 +468,15 @@ echo "ln -s libaccurl.so.4.8.0 libaccurl.so.4" >> /tmp/${LOGFNAME}
 ln -s libaccurl.so.4.8.0 ${LIBDIR}/libaccurl.so.4 || exit 1
 
 installKDF
+installKDFStatus=$?
+
+if [ $BPF_BTF_SUPPORTED -ne 0 ] && [ $installKDFStatus -ne 0 ]; then
+  echo "Error: Failed to install KDF. Exiting installation." >> /tmp/${LOGFNAME}
+  exit 1
+fi
 
 echo "Installing "${NEWTEMP}/plugins/libacnvmctrl.so >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 755 ${NEWTEMP}/plugins/libacnvmctrl.so ${PLUGINDIR} || exit 1
+${INSTALL} -o root -m 755 ${NEWTEMP}/plugins/libacnvmctrl.so ${NVMDIR} || exit 1
 
 echo "Installing "${NEWTEMP}/ACManifestNVM.xml >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 444 ${NEWTEMP}/ACManifestNVM.xml ${INSTPREFIX} || exit 1
@@ -442,6 +489,9 @@ removeTMPDIR
 # In upgrades, we restore the NVM directory from the temp dir
 restoreNVMDirDuringUpgrade
 
+# Move the NVM plugin to the plugins director
+echo "Moving "${NVMDIR}/libacnvmctrl.so >> /tmp/${LOGFNAME}
+mv -f ${NVMDIR}/libacnvmctrl.so ${PLUGINDIR} || exit 1
 
 echo "${CLIENTNAME} is installed successfully."
 echo "${CLIENTNAME} is installed successfully." >> /tmp/${LOGFNAME}
