@@ -24,7 +24,7 @@ checkInstalledHSVersion()
   # version of HS being installed has to be greater than the current HS version
   if [ -f ${HSMANIFEST} ]; then
       HSPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${HSMANIFEST})
-      HSCURRVERSION=5.1.10.233
+      HSCURRVERSION=5.1.11.388
 
       existing_ver="$(csc_vercmp "$HSPREVVERSION" "$HSCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -106,10 +106,10 @@ SYSVLEVELS="2 3 4 5"
 CURRENTDIR=`dirname $0 2> /dev/null`
 VPNMANIFEST="${CSC_INSTPREFIX}/ACManifestVPN.xml"
 
-LOGFNAME=`/bin/date "+posture-5.1.10.233-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=`/usr/bin/date "+posture-5.1.10.233-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=`date "+posture-5.1.10.233-install-%H%M%S%d%m%Y.log"` ||
-  LOGFNAME=posture-5.1.10.233-install.log
+LOGFNAME=`/bin/date "+posture-5.1.11.388-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=`/usr/bin/date "+posture-5.1.11.388-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=`date "+posture-5.1.11.388-install-%H%M%S%d%m%Y.log"` ||
+  LOGFNAME=posture-5.1.11.388-install.log
 
 DIR=`dirname $0 2> /dev/null` || 
   DIR=`/usr/bin/dirname $0 2> /dev/null` || 
@@ -150,7 +150,7 @@ do
 done
 
 echo "Installing Cisco Secure Client - Secure Firewall Posture..."
-echo "Installing Cisco Secure Client - Secure Firewall Posture v5.1.10.233..." > /tmp/${LOGFNAME}
+echo "Installing Cisco Secure Client - Secure Firewall Posture v5.1.11.388..." > /tmp/${LOGFNAME}
 echo `whoami` "invoked $0 from " `pwd` " at " `date` >> /tmp/${LOGFNAME}
 echo ""
 
@@ -353,7 +353,7 @@ if [ "x${PREDEPLOY_LAUNCHER}" = "x1" ]; then
 fi
 
 echo "Installing "${DIR}/csc_sfpuiplugin.so >> /tmp/${LOGFNAME}
-${INSTALL} -o root -m 755 ${DIR}/csc_sfpuiplugin.so ${PLUGINDIR} ||
+${INSTALL} -o root -m 755 ${DIR}/csc_sfpuiplugin.so ${BINDIR} ||
     ( echo "failed." && exitInstallation 1 )
 
 echo "Installing "${DIR}/posture_uninstall.sh >> /tmp/${LOGFNAME}
@@ -428,6 +428,11 @@ echo "Updating AC manifest." >> /tmp/${LOGFNAME}
 ${INSTALL} -o root -m 755 ${DIR}/${POSTUREMANIFEST} ${CSC_INSTPREFIX} >> /tmp/${LOGFNAME}
 ${BINDIR}/manifesttool_posture -i ${CSC_INSTPREFIX} ${CSC_INSTPREFIX}/${POSTUREMANIFEST} >> /tmp/${LOGFNAME}
 
+# Move the Posture plugin to the plugins directory
+echo "Moving "${BINDIR}/csc_sfpuiplugin.so >> /tmp/${LOGFNAME}
+mv -f ${BINDIR}/csc_sfpuiplugin.so ${PLUGINDIR} || 
+    ( echo "failed." && exitInstallation 1 )
+
 echo "Done!"
 echo "Done!" >> /tmp/${LOGFNAME}
 
