@@ -7,6 +7,26 @@ CISCO_AC_OBJNAME=123456789012345678901234567890123456789012345678901234567890123
 # CISCO_AC_TIMESTAMP is also required for signing
 # comment is after BASH_BASE_SIZE or else sign tool will find the comment
 
+# Check if the package architecture matches the device architecture
+checkArchitectureCompatibility() 
+{
+    VPNARCH=x86_64 
+
+    # Check the current device architecture
+    ARCH=$(uname -m)
+    if [ "$ARCH" != "x86_64" ] && [ "$ARCH" != "aarch64" ]; then
+        echo "Unknown architecture: $ARCH"
+        exitInstallation 1
+    fi
+
+    # Compare the VPN architecture with the device architecture
+    if [ "$VPNARCH" != "$ARCH" ]; then
+        echo "Architecture mismatch: Installer is for $VPNARCH, but the device is $ARCH."
+        echo "Installation aborted due to architecture mismatch!" >> /tmp/${LOGFNAME}
+        exitInstallation 1
+    fi
+}
+
 csc_vercmp() 
 {
     ver_from="${1:?missing from-version}"
@@ -29,7 +49,7 @@ checkVersionFeasibilityWithStandaloneNVM()
   failed=false
   # version of VPN being installed has to be greater than the installed standalone NVM version
   if [ -f ${NVMMANIFEST} ]; then
-      VPNVERSION=5.1.10.233
+      VPNVERSION=5.1.11.388
       NVMVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
 
       vpn_ver="$(csc_vercmp "$VPNVERSION" "$NVMVERSION")"
@@ -51,7 +71,7 @@ checkInstalledVersion()
   # version of VPN being installed has to be greater than the current VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      VPNCURRVERSION=5.1.10.233
+      VPNCURRVERSION=5.1.11.388
 
       existing_ver="$(csc_vercmp "$VPNPREVVERSION" "$VPNCURRVERSION")"
       if [ "$existing_ver" != older ]; then
@@ -104,7 +124,7 @@ INSTALL=install
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+cisco-secure-client-linux64-5.1.10.233-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+cisco-secure-client-linux64-5.1.11.388-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco Secure Client"
 FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
@@ -159,6 +179,8 @@ if [ -f "license.txt" ]; then
     done
 fi
 
+checkArchitectureCompatibility
+
 checkInstalledVersion
 
 checkVersionFeasibilityWithStandaloneNVM
